Index: src/arm/builtins-arm.cc |
=================================================================== |
--- src/arm/builtins-arm.cc (revision 2967) |
+++ src/arm/builtins-arm.cc (working copy) |
@@ -44,10 +44,10 @@ |
__ str(r1, MemOperand(ip, 0)); |
// The actual argument count has already been loaded into register |
// r0, but JumpToBuiltin expects r0 to contain the number of |
// arguments including the receiver. |
__ add(r0, r0, Operand(1)); |
- __ JumpToBuiltin(ExternalReference(id)); |
+ __ JumpToRuntime(ExternalReference(id)); |
} |
@@ -44,10 +44,10 @@ |
__ str(r1, MemOperand(ip, 0)); |
// The actual argument count has already been loaded into register |
- // r0, but JumpToBuiltin expects r0 to contain the number of |
+ // r0, but JumpToRuntime expects r0 to contain the number of |
// arguments including the receiver. |
__ add(r0, r0, Operand(1)); |